@@ -35,7 +35,7 @@ class DjangoLoader(BaseLoader):
         # any embedded celerybeat process forks.
         signals.beat_embedded_init.connect(self.close_database)
 
-    def now(self):
+    def now(self, **kwargs):
         return now()
 
     def read_configuration(self):
@@ -110,7 +110,6 @@ class DjangoLoader(BaseLoader):
 
         self.close_database()
         self.close_cache()
-        self.import_default_modules()
 
     def import_default_modules(self):
         super(DjangoLoader, self).import_default_modules()
